@@ -30,7 +30,7 @@ class AbstractDoseInfluenceCalculator:
         raise NotImplementedError()
 
     @abstractmethod
-    def computeBeamlets(self, ct: CTImage, plan: RTPlan, outputDir, roi: Optional[ROIMask] = None):
+    def computeBeamlets(self, ct: CTImage, plan: RTPlan, roi: Optional[ROIMask] = None):
         raise NotImplementedError()
 
 class DoseInfluenceCalculatorException(Exception):
